bayespy.inference.vmp.nodes.binomial.BinomialDistribution.compute_phi_from_parents
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialDistribution.compute_phi_from_parents